#
# spec file for package os-maven-plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           os-maven-plugin
Version:        1.7.1
Release:        1.3
Summary:        Maven plugin for generating platform-dependent properties
License:        Apache-2.0
URL:            https://github.com/trustin/os-maven-plugin/
Source0:        https://github.com/trustin/%{name}/archive/%{name}-%{version}.tar.gz
Patch0:         0001-Don-t-fail-on-unknown-arch.patch
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(com.google.code.findbugs:jsr305)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-component-metadata)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.sonatype.oss:oss-parent:pom:)
BuildArch:      noarch

%description
os-maven-plugin is a Maven extension/plugin that generates various
useful platform-dependent project properties normalized from
${os.name} and ${os.arch}.

${os.name} and ${os.arch} are often subtly different between JVM and
operating system versions or they sometimes contain machine-unfriendly
characters such as whitespaces. This plugin tries to remove such
fragmentation so that you can determine the current operating system
and architecture reliably.

%package javadoc
Summary:        API documentation for %{name}

%description javadoc
This package provides %{summary}.

%prep
%setup -q -n %{name}-%{name}-%{version}

%patch -P 0 -p1

# Remove Eclipse plugin
%pom_remove_dep org.eclipse:ui
%pom_remove_plugin :maven-jar-plugin
find -name EclipseStartup.java -delete
find -name plugin.xml -delete

%pom_remove_plugin org.codehaus.mojo:animal-sniffer-maven-plugin

%build
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%dir %{_javadir}/%{name}
%dir %{_mavenpomdir}/%{name}
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%changelog
* Mon Oct 21 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.7.1
  * Changes:
    + Added detection of more RISC-V architectures. #61 #62 #66
  - riscv32 is detected as riscv for backward compatibility
    with 1.7.0.
  - riscv64 is detected as riscv64.
    + Added detection of Elbrus 2000 architecture. #57
    + Added detection of LoongArch64 architecture. #63 #64
    + Fixed the detection logic so that it detects more MacOS
    variants
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Mar 23 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Mon Jan 17 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.7.0
  * Changes:
    + Added a new property os.detected.arch.bitness
    + Added detection of RISC-V architecture, riscv
    + Added an abstraction layer for System property and file
    system access
    + Added thread safety information to Maven plugin metadata
    so that Maven doesn't warn about thread safety anymore
    + Added detection of z/OS operating system
    + Added m2e life cycle mapping metadata so os-maven-plugin
    works better with Eclipse m2e
    + Added support for MIPS and MIPSEL 32/64-bit architecture
    mips_32 - if the value is one of: mips, mips32
    mips_64 - if the value is mips64
    mipsel_32 - if the value is one of: mipsel, mips32el
    mipsel_64 - if the value is mips64el
    + Added support for PPCLE 32-bit architecture
    ppcle_32 - if the value is one of: ppcle, ppc32le
    + Added support for IA64N and IA64W architecture
    itanium_32 - if the value is ia64n
    itanium_64 - if the value is one of: ia64, ia64w (new),
    itanium64
    + Fixed classpath conflicts due to outdated Guava version
    in transitive dependencies
    + Fixed incorrect prerequisite
    + Overall code clean-up and dependency updates
- Modified patch:
  * 0002-Don-t-fail-on-unknown-arch.patch ->
    0001-Don-t-fail-on-unknown-arch.patch
  + Rediff to changed context
- Removed patch:
  * 0001-Port-to-current-plexus-utils.patch
    + not needed any more
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Tue Nov 12 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of os-maven-plugin 1.2.3
